summaryrefslogtreecommitdiffstats
path: root/emacs.d/init.el
diff options
context:
space:
mode:
Diffstat (limited to 'emacs.d/init.el')
-rw-r--r--emacs.d/init.el6
1 files changed, 4 insertions, 2 deletions
diff --git a/emacs.d/init.el b/emacs.d/init.el
index 8c05f38..94c0b13 100644
--- a/emacs.d/init.el
+++ b/emacs.d/init.el
@@ -2,10 +2,12 @@
(add-to-list 'load-path (expand-file-name "~/.emacs.d/site-lisp"))
;; Fix paths on OSX
(when (equal system-type 'darwin)
(setenv "PATH" (concat (getenv "PATH") ":/usr/local/bin"))
- (setq exec-path (append exec-path '("/usr/local/bin"))))
+ (setq exec-path (append exec-path '("/usr/local/bin")))
+ (global-set-key [home] 'move-beginning-of-line)
+ (global-set-key [end] 'move-end-of-line))
(setq-default
gc-cons-threshold 10000000
@@ -2,10 +2,12 @@
(add-to-list 'load-path (expand-file-name "~/.emacs.d/site-lisp"))
-;; Fix paths on OSX
+;; Fix paths and key bindings on OSX
(when (equal system-type 'darwin)
(setenv "PATH" (concat (getenv "PATH") ":/usr/local/bin"))